package com.test.list;

import android.app.ListActivity;
import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.TreeSet;

public class ListaComSecoes extends ListActivity {

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        ListaAdapter adapter = new ListaAdapter();
        adapter.adicionarSeparador("Seo");
        for (int i = 1; i < 10; i++) {
            adapter.adicionarItem("Item " + i);
            if (i % 2 == 0) {
                adapter.adicionarSeparador("Seo");
            }
        }
        setListAdapter(adapter);
    }

    private class ListaAdapter extends BaseAdapter {

        private static final int TIPO_ITEM = 0;
        private static final int TIPO_ITEM2 = 1;
        private static final int TIPO_SEPARATOR = 2;

        private ArrayList<String> itens = new ArrayList<String>();
        private LayoutInflater inflater;

        private TreeSet<Integer> separadores = new TreeSet<Integer>();

        public ListaAdapter() {
            inflater = (LayoutInflater)getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        }

        public void adicionarItem(final String item) {
            itens.add(item);
            notifyDataSetChanged();
        }

        public void adicionarSeparador(final String item) {
            itens.add(item);
            separadores.add(itens.size() - 1);
            notifyDataSetChanged();
        }

        @Override
        public int getItemViewType(int position) {
        	if (separadores.contains(position)) 
        		return TIPO_SEPARATOR;
        	else {
        		if (position % 2 == 0)
        			return TIPO_ITEM;
        		else
        			return TIPO_ITEM2;
        	}
        }

        @Override
        public int getViewTypeCount() {
            return 3;
        }

        @Override
        public int getCount() {
            return itens.size();
        }

        @Override
        public String getItem(int position) {
            return itens.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            ViewHolder holder = null;
            int tipo = getItemViewType(position);
            
            if (convertView == null) {
                holder = new ViewHolder();
                switch (tipo) {
                    case TIPO_ITEM:
                        convertView = inflater.inflate(R.layout.item1, null);
                        holder.textView = (TextView)convertView.findViewById(android.R.id.text1);
                        break;
                    case TIPO_ITEM2:
                        convertView = inflater.inflate(R.layout.item2, null);
                        holder.textView = (TextView)convertView.findViewById(android.R.id.text1);
                        break;
                    case TIPO_SEPARATOR:
                        convertView = inflater.inflate(R.layout.separador, null);
                        holder.textView = (TextView)convertView.findViewById(android.R.id.text1);
                        break;
                }
                convertView.setTag(holder);
            } else {
                holder = (ViewHolder)convertView.getTag();
            }
            
            holder.textView.setText(itens.get(position));
            return convertView;
        }
    }

    public static class ViewHolder {
        public TextView textView;
    }
}
